@@ -1,5 +1,12 @@
 lhsDesign <- function(n, dimension, randomized=TRUE, seed=NULL){
   
+  # arguments : n         = number of points
+  #             dimension = number of variables
+  #  	    randomized = logical for randomized or centered points
+  #             seed       = value of the random seed
+  # output : a list containing the arguments and the LHS design
+  
+  
   # if no seed is provided in argument, choice of the seed for 'runif' and 'sample'
   if (is.null(seed)){
     seed <- as.numeric(Sys.time())
@@ -7,7 +14,7 @@ lhsDesign <- function(n, dimension, randomized=TRUE, seed=NULL){
   set.seed(seed)
   
   # Randomized LHS: U[0,1]-sampling of n x dim values
-  if (randomized==T) ran = matrix(runif(n*dimension),nrow=n,ncol=dimension) 
+  if (randomized) ran = matrix(runif(n*dimension),nrow=n,ncol=dimension) 
   # Centered LHS
   else ran = matrix(0.5,nrow=n,ncol=dimension) 
     
